/*
 * Copyright (c) 2005-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id:
 */
package edu.indiana.extreme.xbaya;

import java.io.File;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import xsul.lead.LeadDeploymentConfig;
import xsul5.MLogger;
import edu.indiana.extreme.xbaya.file.XBayaPathConstants;

/**
 * @author Satoshi Shirasuna
 */
public class XBayaConfiguration {

    private static final MLogger logger = MLogger.getLogger();

    private String title = XBayaConstants.APPLICATION_NAME;

    private String workflow = null;

    private List<String> localRegistris = new ArrayList<String>();

    // GPEL Engine related

    private URI gpelEngineURL = XBayaConstants.DEFAULT_GPEL_ENGINE_URL;

    private URI gpelTemplateID = null;

    private URI gpelInstanceID = null;

    /**
     * No default value. If the URL is not specified, XBaya doesn't use a
     * resource catalog.
     */
    private URI resourceCatalogURL;

    private URI gfacURL = XBayaConstants.DEFAULT_GFAC_URL;

    private URI gfacRegistryURL = XBayaConstants.DEFAULT_GFAC_REGISTRY_URL;

    /**
     * No default value. If the URL is not specified, XBaya doesn't use an
     * XResigtry.
     */
    private URI xRegistryURL;

    private URI dscURL = XBayaConstants.DEFAULT_DSC_URL;

    // MyLead related

    private URI myLeadAgentURL = XBayaConstants.DEFAULT_MYLEAD_AGENT_URL;

    private String myLeadUser = null;

    private String myLeadProject = null;

    private String myLeadWorkflow = null;

    private String myLeadSampleUser = XBayaConstants.DEFAULT_MYLEAD_SAMPLE_USER;

    private String myLeadSampleProject = XBayaConstants.DEFAULT_MYLEAD_SAMPLE_PROJECT_ID;

    // Monitor related

    private boolean startMonitor = false;

    private URI brokerURL = XBayaConstants.DEFAULT_BROKER_URL;

    private String topic = null;

    private boolean pullMode = true;

    private URI messageBoxURL = XBayaConstants.DEFAULT_MESSAGE_BOX_URL;

    // Kerma

    private URI karmaURL = null;

    private URI kermaWorkflowInstanceID = null;

    // MyProxy

    private String myProxyServer = XBayaConstants.DEFAULT_MYPROXY_SERVER;

    private int myProxyPort = XBayaConstants.DEFAULT_MYPROXY_PORT;

    private int myProxyLifetime = XBayaConstants.DEFAULT_MYPROXY_LIFTTIME;

    private String myProxyUsername = null;

    private String myProxyPassphrase = null;

    private boolean loadMyProxy = false;

    // Size

    private int width;

    private int height;

    // Errors

    private List<Throwable> errors;

    /**
     * Constructs an XwfConfiguration.
     */
    public XBayaConfiguration() {
        this.errors = new ArrayList<Throwable>();

        // Read from system properties first.
        String systemConfig = System.getProperty("xbaya.config");
        try {
            if (systemConfig != null) {
                loadConfiguration(systemConfig);
            }
        } catch (RuntimeException e) {
            String message = "Error while reading a configuration file, "
                    + systemConfig;
            logger.warning(message, e);
        }
    }

    /**
     * @param configFilePath
     */
    public void loadConfiguration(String configFilePath) {
        File configFile = new File(configFilePath);
        URI uri = configFile.toURI();
        loadConfiguration(uri);
    }

    private void loadConfiguration(URI uri) {
        LeadDeploymentConfig config = LeadDeploymentConfig
                .loadConfig(null, uri);
        URI gpel = config.getGpelUrl();
        if (gpel != null) {
            this.gpelEngineURL = config.getGpelUrl();
        }
        URI rescat = config.getResourceCatalogUrl();
        if (rescat != null) {
            this.resourceCatalogURL = rescat;
        }
        URI gfac = config.getGfacUrl();
        if (gfac != null) {
            this.gfacURL = gfac;
        }
        URI dsc = config.getDscUrl();
        if (dsc != null) {
            this.dscURL = dsc;
        }
        URI mylead = config.getMyLeadAgentUrl();
        if (mylead != null) {
            this.myLeadAgentURL = mylead;
        }
        URI broker = config.getBrokerUrl();
        if (broker != null) {
            this.brokerURL = broker;
        }
        URI msgBox = config.getMsgBoxUrl();
        if (msgBox != null) {
            this.messageBoxURL = msgBox;
        }
    }

    /**
     * Returns the title.
     * 
     * @return The title
     */
    public String getTitle() {
        return this.title;
    }

    /**
     * Sets title.
     * 
     * @param title
     *            The title to set.
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * Returns the defaultWorkflow.
     * 
     * @return The defaultWorkflow
     */
    public String getWorkflow() {
        return this.workflow;
    }

    /**
     * Sets defaultWorkflow.
     * 
     * @param defaultWorkflow
     *            The defaultWorkflow to set.
     */
    public void setWorkflow(String defaultWorkflow) {
        this.workflow = defaultWorkflow;
    }

    /**
     * Enable the system default local registry.
     */
    public void enableLocalRegistry() {
        addLocalRegistry(XBayaPathConstants.WSDL_DIRECTORY);
    }

    /**
     * @param path
     *            The path of local registry.
     */
    public void addLocalRegistry(String path) {
        this.localRegistris.add(path);
    }

    /**
     * @return The list of pathes of local registries.
     */
    public List<String> getLocalRegistry() {
        return this.localRegistris;
    }

    /**
     * Returns the gpelEngineUrl.
     * 
     * @return The gpelEngineUrl
     */
    public URI getGPELEngineURL() {
        return this.gpelEngineURL;
    }

    /**
     * Sets gpelEngineUrl.
     * 
     * @param gpelEngineURL
     *            The gpelEngineUrl to set.
     */
    public void setGPELEngineURL(URI gpelEngineURL) {
        this.gpelEngineURL = gpelEngineURL;
    }

    /**
     * @param templateID
     */
    public void setGPELTemplateID(URI templateID) {
        this.gpelTemplateID = templateID;
    }

    /**
     * @return The GPEL template ID.
     */
    public URI getGPELTemplateID() {
        return this.gpelTemplateID;
    }

    /**
     * Returns the gpelInstanceID.
     * 
     * @return The gpelInstanceID
     */
    public URI getGPELInstanceID() {
        return this.gpelInstanceID;
    }

    /**
     * Sets gpelInstanceID.
     * 
     * @param gpelInstanceID
     *            The gpelInstanceID to set.
     */
    public void setGPELInstanceID(URI gpelInstanceID) {
        this.gpelInstanceID = gpelInstanceID;
    }

    /**
     * Returns the resourceCatalogUrl.
     * 
     * @return The resourceCatalogUrl
     */
    public URI getResourceCatalogURL() {
        return this.resourceCatalogURL;
    }

    /**
     * Sets resourceCatalogUrl.
     * 
     * @param resourceCatalogURL
     *            The resourceCatalogUrl to set.
     */
    public void setResourceCatalogURL(URI resourceCatalogURL) {
        this.resourceCatalogURL = resourceCatalogURL;
    }

    /**
     * @return The GFac URL
     */
    public URI getGFacURL() {
        return this.gfacURL;
    }

    /**
     * @param gfacURL
     */
    public void setGFacURL(URI gfacURL) {
        this.gfacURL = gfacURL;
    }

    /**
     * Returns the gfacRegistryURL.
     * 
     * @return The gfacRegistryURL
     */
    public URI getGFacRegistryURL() {
        return this.gfacRegistryURL;
    }

    /**
     * Sets gfacRegistryURL.
     * 
     * @param gfacRegistryURL
     *            The gfacRegistryURL to set.
     */
    public void setGFacRegistryURL(URI gfacRegistryURL) {
        this.gfacRegistryURL = gfacRegistryURL;
    }

    /**
     * Returns the xRegistryURL.
     * 
     * @return The xRegistryURL
     */
    public URI getXRegistryURL() {
        return this.xRegistryURL;
    }

    /**
     * Sets registryURL.
     * 
     * @param registryURL
     *            The xRegistryURL to set.
     */
    public void setXRegistryURL(URI registryURL) {
        this.xRegistryURL = registryURL;
    }

    /**
     * @return The DSC URL
     */
    public URI getDSCURL() {
        return this.dscURL;
    }

    /**
     * @param dscURL
     */
    public void setDSCURL(URI dscURL) {
        this.dscURL = dscURL;
    }

    /**
     * Returns the myLeadAgentUrl.
     * 
     * @return The myLeadAgentUrl
     */
    public URI getMyLeadAgentURL() {
        return this.myLeadAgentURL;
    }

    /**
     * Sets myLeadAgentUrl.
     * 
     * @param myLeadAgentURL
     *            The myLeadAgentUrl to set.
     */
    public void setMyLeadAgentURL(URI myLeadAgentURL) {
        this.myLeadAgentURL = myLeadAgentURL;
    }

    /**
     * Returns the myLeadProject.
     * 
     * @return The myLeadProject
     */
    public String getMyLeadProject() {
        return this.myLeadProject;
    }

    /**
     * Sets myLeadProject.
     * 
     * @param myLeadProject
     *            The myLeadProject to set.
     */
    public void setMyLeadProject(String myLeadProject) {
        this.myLeadProject = myLeadProject;
    }

    /**
     * Returns the myLeadUser.
     * 
     * @return The myLeadUser
     */
    public String getMyLeadUser() {
        return this.myLeadUser;
    }

    /**
     * Sets myLeadUser.
     * 
     * @param myLeadUser
     *            The myLeadUser to set.
     */
    public void setMyLeadUser(String myLeadUser) {
        this.myLeadUser = myLeadUser;
    }

    /**
     * Returns the myLeadWorkflow.
     * 
     * @return The myLeadWorkflow
     */
    public String getMyLeadWorkflow() {
        return this.myLeadWorkflow;
    }

    /**
     * Sets myLeadWorkflow.
     * 
     * @param myLeadWorkflow
     *            The myLeadWorkflow to set.
     */
    public void setMyLeadWorkflow(String myLeadWorkflow) {
        this.myLeadWorkflow = myLeadWorkflow;
    }

    /**
     * Returns the myLeadSampleProject.
     * 
     * @return The myLeadSampleProject
     */
    public String getMyLeadSampleProject() {
        return this.myLeadSampleProject;
    }

    /**
     * Sets myLeadSampleProject.
     * 
     * @param myLeadSampleProject
     *            The myLeadSampleProject to set.
     */
    public void setMyLeadSampleProject(String myLeadSampleProject) {
        this.myLeadSampleProject = myLeadSampleProject;
    }

    /**
     * Returns the myLeadSampleUser.
     * 
     * @return The myLeadSampleUser
     */
    public String getMyLeadSampleUser() {
        return this.myLeadSampleUser;
    }

    /**
     * Sets myLeadSampleUser.
     * 
     * @param myLeadSampleUser
     *            The myLeadSampleUser to set.
     */
    public void setMyLeadSampleUser(String myLeadSampleUser) {
        this.myLeadSampleUser = myLeadSampleUser;
    }

    /**
     * Returns the topic.
     * 
     * @return The topic
     */
    public String getTopic() {
        return this.topic;
    }

    /**
     * Sets topic.
     * 
     * @param topic
     *            The topic to set.
     */
    public void setTopic(String topic) {
        this.topic = topic;
    }

    /**
     * Returns the messageBoxUrl.
     * 
     * @return The messageBoxUrl
     */
    public URI getMessageBoxURL() {
        return this.messageBoxURL;
    }

    /**
     * Sets messageBoxUrl.
     * 
     * @param messageBoxURL
     *            The messageBoxUrl to set.
     */
    public void setMessageBoxURL(URI messageBoxURL) {
        this.messageBoxURL = messageBoxURL;
    }

    /**
     * Returns the pullMode.
     * 
     * @return The pullMode
     */
    public boolean isPullMode() {
        return this.pullMode;
    }

    /**
     * Sets pullMode.
     * 
     * @param pullMode
     *            The pullMode to set.
     */
    public void setPullMode(boolean pullMode) {
        this.pullMode = pullMode;
    }

    /**
     * Returns the brokerLocation.
     * 
     * @return The brokerLocation
     */
    public URI getBrokerURL() {
        return this.brokerURL;
    }

    /**
     * Sets brokerLocation.
     * 
     * @param brokerURL
     *            The brokerLocation to set.
     */
    public void setBrokerURL(URI brokerURL) {
        this.brokerURL = brokerURL;
    }

    /**
     * Returns the startMonitor.
     * 
     * @return The startMonitor
     */
    public boolean isStartMonitor() {
        return this.startMonitor;
    }

    /**
     * Sets startMonitor.
     * 
     * @param startMonitor
     *            The startMonitor to set.
     */
    public void setStartMonitor(boolean startMonitor) {
        this.startMonitor = startMonitor;
    }

    /**
     * Returns the kermaURI.
     * 
     * @return The kermaURI
     */
    public URI getKarmaURL() {
        return this.karmaURL;
    }

    /**
     * Sets kermaURI.
     * 
     * @param kermaURI
     *            The kermaURI to set.
     */
    public void setKarmaURL(URI kermaURI) {
        this.karmaURL = kermaURI;
    }

    /**
     * Returns the kermaWorkflowInstanceID.
     * 
     * @return The kermaWorkflowInstanceID
     */
    public URI getKermaWorkflowInstanceID() {
        return this.kermaWorkflowInstanceID;
    }

    /**
     * Sets kermaWorkflowInstanceID.
     * 
     * @param kermaWorkflowInstanceID
     *            The kermaWorkflowInstanceID to set.
     */
    public void setKermaWorkflowInstanceID(URI kermaWorkflowInstanceID) {
        this.kermaWorkflowInstanceID = kermaWorkflowInstanceID;
    }

    /**
     * Returns the myProxyServer.
     * 
     * @return The myProxyServer
     */
    public String getMyProxyServer() {
        return this.myProxyServer;
    }

    /**
     * Sets myProxyServer.
     * 
     * @param myProxyServer
     *            The myProxyServer to set.
     */
    public void setMyProxyServer(String myProxyServer) {
        this.myProxyServer = myProxyServer;
    }

    /**
     * Returns the myProxyPort.
     * 
     * @return The myProxyPort
     */
    public int getMyProxyPort() {
        return this.myProxyPort;
    }

    /**
     * Sets myProxyPort.
     * 
     * @param myProxyPort
     *            The myProxyPort to set.
     */
    public void setMyProxyPort(int myProxyPort) {
        this.myProxyPort = myProxyPort;
    }

    /**
     * Returns the myProxyLifetime.
     * 
     * @return The myProxyLifetime
     */
    public int getMyProxyLifetime() {
        return this.myProxyLifetime;
    }

    /**
     * Sets myProxyLifetime.
     * 
     * @param myProxyLifetime
     *            The myProxyLifetime to set.
     */
    public void setMyProxyLifetime(int myProxyLifetime) {
        this.myProxyLifetime = myProxyLifetime;
    }

    /**
     * Returns the myProxyUsername.
     * 
     * @return The myProxyUsername
     */
    public String getMyProxyUsername() {
        return this.myProxyUsername;
    }

    /**
     * Sets myProxyUsername.
     * 
     * @param myProxyUsername
     *            The myProxyUsername to set.
     */
    public void setMyProxyUsername(String myProxyUsername) {
        this.myProxyUsername = myProxyUsername;
    }

    /**
     * Returns the myProxyPassphrase.
     * 
     * @return The myProxyPassphrase
     */
    public String getMyProxyPassphrase() {
        return this.myProxyPassphrase;
    }

    /**
     * Sets myProxyPassphrase.
     * 
     * @param myProxyPassphrase
     *            The myProxyPassphrase to set.
     */
    public void setMyProxyPassphrase(String myProxyPassphrase) {
        this.myProxyPassphrase = myProxyPassphrase;
    }

    /**
     * Returns the loadMyProxy.
     * 
     * @return The loadMyProxy
     */
    public boolean isLoadMyProxy() {
        return this.loadMyProxy;
    }

    /**
     * Sets loadMyProxy.
     * 
     * @param loadMyProxy
     *            The loadMyProxy to set.
     */
    public void setLoadMyProxy(boolean loadMyProxy) {
        this.loadMyProxy = loadMyProxy;
    }

    /**
     * Returns the height.
     * 
     * @return The height
     */
    public int getHeight() {
        return this.height;
    }

    /**
     * Sets height.
     * 
     * @param height
     *            The height to set.
     */
    public void setHeight(int height) {
        this.height = height;
    }

    /**
     * Returns the width.
     * 
     * @return The width
     */
    public int getWidth() {
        return this.width;
    }

    /**
     * Sets width.
     * 
     * @param width
     *            The width to set.
     */
    public void setWidth(int width) {
        this.width = width;
    }

    /**
     * Add an error.
     * 
     * @param e
     */
    public void addError(Throwable e) {
        this.errors.add(e);
    }

    /**
     * Returns errors.
     * 
     * @return Errors.
     */
    public Iterable<Throwable> getErrors() {
        return this.errors;
    }

}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2005-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
